
/*  A Bison parser, made from config_parse.y
    by GNU Bison version 1.28  */

#define YYBISON 1  /* Identify Bison output.  */

#define	ADDEXTICON	257
#define	ADDMIMEICON	258
#define	DEFAULTDIRICON	259
#define	DEFAULTDISKICON	260
#define	DEFAULTFILEICON	261
#define	DEFAULTUNREADABLEICON	262
#define	DEFAULTVFSICON	263
#define	DEFAULTOPENEDDIRICON	264
#define	DEFAULTOPENEDDISKICON	265
#define	DEFAULTOPENEDVFSICON	266
#define	MOUNTPROGRAM	267
#define	UMOUNTPROGRAM	268
#define	EJECTPROGRAM	269
#define	MOUNTPOINT	270
#define	USEAUTOMOUNT	271
#define	MOUNTRETRY	272
#define	EXTENSION	273
#define	OPTIONDUS	274
#define	OPTIONWARNMOUNT	275
#define	OPTIONEJECT	276
#define	COMPRESSIONLEVEL	277
#define	TESTVFS	278
#define	VFSEXTENSION	279
#define	MIMEEXTENSION	280
#define	MIMEVFSEXTENSION	281
#define	READINFORMATION	282
#define	DEFAULTMIMEEXTENSION	283
#define	SCANMIMETYPES	284
#define	ADDMIMETOSKIP	285
#define	USEDEFAULTMIMEPLUGIN	286
#define	DBCLICKFORINFO	287
#define	DISPLAYDIRSIZE	288
#define	DATEFORMAT	289
#define	RECENTFILE	290
#define	RECENTFILESMAX	291
#define	PREVIOUSSEARCHMODE	292
#define	SAVEONLYUSEDCATEGORIES	293
#define	MAINWINDOWPOSITION	294
#define	STRING	295
#define	QSTRING	296
#define	GBOOLEAN	297
#define	STRINGLOCALE	298
#define	INTEGER	299
#define	EOL	300

#line 20 "config_parse.y"

#include <config.h>
#include <stdio.h>
#include <stdlib.h>
#include <glib.h>
#include "config_common.h"
#include "interface.h"
#include "io.h"
#include "setup.h"

GList *local_config;


#line 34 "config_parse.y"
typedef union {
	gint		val;
	char		*string;
	gboolean        gbool;  
	GString		*gstring;
	GArray		*garray;
	GList		*glist;
	KEY_VALUE	*kv;
} YYSTYPE;
#include <stdio.h>

#ifndef __cplusplus
#ifndef __STDC__
#define const
#endif
#endif



#define	YYFINAL		194
#define	YYFLAG		-32768
#define	YYNTBASE	47

#define YYTRANSLATE(x) ((unsigned)(x) <= 300 ? yytranslate[x] : 90)

static const char yytranslate[] = {     0,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     1,     3,     4,     5,     6,
     7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
    17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
    27,    28,    29,    30,    31,    32,    33,    34,    35,    36,
    37,    38,    39,    40,    41,    42,    43,    44,    45,    46
};

#if YYDEBUG != 0
static const short yyprhs[] = {     0,
     0,     2,     5,     7,    10,    13,    16,    19,    22,    25,
    28,    31,    34,    37,    40,    43,    46,    49,    52,    55,
    58,    61,    64,    67,    70,    73,    76,    79,    82,    85,
    88,    91,    94,    97,   100,   103,   106,   109,   112,   115,
   118,   121,   123,   131,   137,   141,   152,   163,   166,   169,
   172,   175,   178,   181,   184,   187,   190,   193,   196,   199,
   202,   205,   208,   211,   214,   217,   220,   223,   226,   229,
   232,   235,   238,   241,   244,   247,   250,   253,   256,   259,
   263,   270,   272,   275,   277
};

static const short yyrhs[] = {    48,
     0,    49,    48,     0,    49,     0,    70,    46,     0,    71,
    46,     0,    72,    46,     0,    73,    46,     0,    74,    46,
     0,    75,    46,     0,    76,    46,     0,    77,    46,     0,
    78,    46,     0,    79,    46,     0,    55,    46,     0,    56,
    46,     0,    59,    46,     0,    60,    46,     0,    57,    46,
     0,    58,    46,     0,    63,    46,     0,    62,    46,     0,
    61,    46,     0,    64,    46,     0,    65,    46,     0,    50,
    46,     0,    53,    46,     0,    51,    46,     0,    54,    46,
     0,    52,    46,     0,    85,    46,     0,    86,    46,     0,
    67,    46,     0,    66,    46,     0,    68,    46,     0,    69,
    46,     0,    80,    46,     0,    81,    46,     0,    82,    46,
     0,    83,    46,     0,    84,    46,     0,    87,    46,     0,
    46,     0,    19,    89,    89,    89,    89,    89,    45,     0,
    26,    89,    89,    89,    45,     0,    29,    89,    89,     0,
    25,    89,    89,    89,    89,    45,    89,    45,    45,    45,
     0,    27,    89,    89,    89,    89,    45,    89,    45,    45,
    45,     0,    13,    89,     0,    14,    89,     0,    15,    89,
     0,    16,    89,     0,    17,    43,     0,    18,    45,     0,
    20,    43,     0,    21,    43,     0,    22,    43,     0,    23,
    45,     0,    24,    45,     0,    28,    43,     0,    32,    43,
     0,    33,    43,     0,    34,    43,     0,     3,    88,     0,
     4,    88,     0,     7,    89,     0,     5,    89,     0,     6,
    89,     0,     8,    89,     0,     9,    89,     0,    10,    89,
     0,    11,    89,     0,    12,    89,     0,    35,    89,     0,
    35,    44,     0,    36,    89,     0,    37,    45,     0,    38,
    45,     0,    39,    43,     0,    30,    43,     0,    31,    89,
    45,     0,    40,    45,    45,    45,    45,    43,     0,    89,
     0,    89,    88,     0,    41,     0,    42,     0
};

#endif

#if YYDEBUG != 0
static const short yyrline[] = { 0,
   180,   183,   190,   199,   200,   201,   202,   203,   204,   205,
   206,   207,   208,   209,   210,   211,   212,   213,   214,   215,
   216,   217,   218,   219,   220,   221,   222,   223,   224,   225,
   226,   227,   228,   229,   230,   231,   232,   233,   234,   235,
   236,   237,   240,   272,   295,   315,   350,   378,   389,   400,
   411,   421,   431,   442,   452,   462,   473,   484,   495,   506,
   517,   530,   546,   557,   568,   579,   590,   601,   612,   623,
   634,   645,   656,   665,   676,   694,   705,   716,   727,   738,
   750,   767,   768,   771,   772
};
#endif


#if YYDEBUG != 0 || defined (YYERROR_VERBOSE)

static const char * const yytname[] = {   "$","error","$undefined.","ADDEXTICON",
"ADDMIMEICON","DEFAULTDIRICON","DEFAULTDISKICON","DEFAULTFILEICON","DEFAULTUNREADABLEICON",
"DEFAULTVFSICON","DEFAULTOPENEDDIRICON","DEFAULTOPENEDDISKICON","DEFAULTOPENEDVFSICON",
"MOUNTPROGRAM","UMOUNTPROGRAM","EJECTPROGRAM","MOUNTPOINT","USEAUTOMOUNT","MOUNTRETRY",
"EXTENSION","OPTIONDUS","OPTIONWARNMOUNT","OPTIONEJECT","COMPRESSIONLEVEL","TESTVFS",
"VFSEXTENSION","MIMEEXTENSION","MIMEVFSEXTENSION","READINFORMATION","DEFAULTMIMEEXTENSION",
"SCANMIMETYPES","ADDMIMETOSKIP","USEDEFAULTMIMEPLUGIN","DBCLICKFORINFO","DISPLAYDIRSIZE",
"DATEFORMAT","RECENTFILE","RECENTFILESMAX","PREVIOUSSEARCHMODE","SAVEONLYUSEDCATEGORIES",
"MAINWINDOWPOSITION","STRING","QSTRING","GBOOLEAN","STRINGLOCALE","INTEGER",
"EOL","config_file","lines","one_line","line_EXTENSION","line_MIMEEXTENSION",
"line_DEFAULTMIMEEXTENSION","line_VFSEXTENSION","line_MIMEVFSEXTENSION","line_MOUNTPROGRAM",
"line_UMOUNTPROGRAM","line_EJECTPROGRAM","line_MOUNTPOINT","line_USEAUTOMOUNT",
"line_MOUNTRETRY","line_OPTIONDUS","line_OPTIONWARNMOUNT","line_OPTIONEJECT",
"line_COMPRESSIONLEVEL","line_TESTVFS","line_READINFORMATION","line_USEDEFAULTMIMEPLUGIN",
"line_DBCLICKFORINFO","line_DISPLAYDIRSIZE","line_ADDEXTICON","line_ADDMIMEICON",
"line_DEFAULTFILEICON","line_DEFAULTDIRICON","line_DEFAULTDISKICON","line_DEFAULTUNREADABLEICON",
"line_DEFAULTVFSICON","line_DEFAULTOPENEDDIRICON","line_DEFAULTOPENEDDISKICON",
"line_DEFAULTOPENEDVFSICON","line_DATEFORMAT","line_RECENTFILE","line_RECENTFILESMAX",
"line_PREVIOUSSEARCHMODE","line_SAVEONLYUSEDCATEGORIES","line_SCANMIMETYPES",
"line_ADDMIMETOSKIP","line_MAINWINDOWPOSITION","STRINGS","GSTRING", NULL
};
#endif

static const short yyr1[] = {     0,
    47,    48,    48,    49,    49,    49,    49,    49,    49,    49,
    49,    49,    49,    49,    49,    49,    49,    49,    49,    49,
    49,    49,    49,    49,    49,    49,    49,    49,    49,    49,
    49,    49,    49,    49,    49,    49,    49,    49,    49,    49,
    49,    49,    50,    51,    52,    53,    54,    55,    56,    57,
    58,    59,    60,    61,    62,    63,    64,    65,    66,    67,
    68,    69,    70,    71,    72,    73,    74,    75,    76,    77,
    78,    79,    80,    80,    81,    82,    83,    84,    85,    86,
    87,    88,    88,    89,    89
};

static const short yyr2[] = {     0,
     1,     2,     1,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     1,     7,     5,     3,    10,    10,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     3,
     6,     1,     2,     1,     1
};

static const short yydefact[] = {     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,    42,     1,
     3,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,    84,
    85,    63,    82,    64,    66,    67,    65,    68,    69,    70,
    71,    72,    48,    49,    50,    51,    52,    53,     0,    54,
    55,    56,    57,    58,     0,     0,     0,    59,     0,    79,
     0,    60,    61,    62,    74,    73,    75,    76,    77,    78,
     0,     2,    25,    27,    29,    26,    28,    14,    15,    18,
    19,    16,    17,    22,    21,    20,    23,    24,    33,    32,
    34,    35,     4,     5,     6,     7,     8,     9,    10,    11,
    12,    13,    36,    37,    38,    39,    40,    30,    31,    41,
    83,     0,     0,     0,     0,    45,    80,     0,     0,     0,
     0,     0,     0,     0,     0,    44,     0,     0,     0,     0,
     0,    81,    43,     0,     0,     0,     0,     0,     0,    46,
    47,     0,     0,     0
};

static const short yydefgoto[] = {   192,
    40,    41,    42,    43,    44,    45,    46,    47,    48,    49,
    50,    51,    52,    53,    54,    55,    56,    57,    58,    59,
    60,    61,    62,    63,    64,    65,    66,    67,    68,    69,
    70,    71,    72,    73,    74,    75,    76,    77,    78,    79,
    82,    83
};

static const short yypact[] = {    29,
   -14,   -14,   -14,   -14,   -14,   -14,   -14,   -14,   -14,   -14,
   -14,   -14,   -14,   -14,   -30,   -28,   -14,   -24,   -20,   -18,
   -16,    25,   -14,   -14,   -14,    28,   -14,    30,   -14,    31,
    33,    34,   -26,   -14,    27,    35,    36,    37,-32768,-32768,
    29,    32,    38,    39,    40,    41,    42,    43,    44,    45,
    46,    48,    49,    51,    52,    53,    54,    55,    59,    61,
    62,    63,    64,    65,    66,    67,    68,    69,    70,    71,
    72,    73,    74,    75,    76,    77,    78,    79,    80,-32768,
-32768,-32768,   -14,-32768,-32768,-32768,-32768,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,   -14,-32768,
-32768,-32768,-32768,-32768,   -14,   -14,   -14,-32768,   -14,-32768,
    82,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,
    83,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,
-32768,   -14,   -14,   -14,   -14,-32768,-32768,    84,   -14,   -14,
    85,   -14,    86,   -14,    87,-32768,    88,    91,    90,   -14,
   -14,-32768,-32768,    92,    93,    94,    95,    96,    97,-32768,
-32768,    81,   136,-32768
};

static const short yypgoto[] = {-32768,
   102,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,
    10,    -3
};


#define	YYLAST		178


static const short yytable[] = {    85,
    86,    87,    88,    89,    90,    91,    92,    93,    94,    95,
    96,    84,    97,    99,    80,    81,    98,   115,   100,   105,
   106,   107,   101,   109,   102,   111,    80,    81,   103,   116,
   117,     1,     2,     3,     4,     5,     6,     7,     8,     9,
    10,    11,    12,    13,    14,    15,    16,    17,    18,    19,
    20,    21,    22,    23,    24,    25,    26,    27,    28,    29,
    30,    31,    32,    33,    34,    35,    36,    37,    38,   104,
   108,   118,   110,   112,    39,   113,   114,   123,   120,   119,
   193,   121,     0,   124,   125,   126,   127,   128,   129,   130,
   131,   132,   161,   133,   134,   162,   135,   136,   137,   138,
   139,   163,   164,   165,   140,   166,   141,   142,   143,   144,
   145,   146,   147,   148,   149,   150,   151,   152,   153,   154,
   155,   156,   157,   158,   159,   160,   167,   168,   173,   176,
   178,   180,   181,   182,   183,   194,   186,   187,   188,   189,
   190,   191,   122,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   169,   170,
   171,   172,     0,     0,     0,   174,   175,     0,   177,     0,
   179,     0,     0,     0,     0,     0,   184,   185
};

static const short yycheck[] = {     3,
     4,     5,     6,     7,     8,     9,    10,    11,    12,    13,
    14,     2,    43,    17,    41,    42,    45,    44,    43,    23,
    24,    25,    43,    27,    43,    29,    41,    42,    45,    33,
    34,     3,     4,     5,     6,     7,     8,     9,    10,    11,
    12,    13,    14,    15,    16,    17,    18,    19,    20,    21,
    22,    23,    24,    25,    26,    27,    28,    29,    30,    31,
    32,    33,    34,    35,    36,    37,    38,    39,    40,    45,
    43,    45,    43,    43,    46,    43,    43,    46,    43,    45,
     0,    45,    -1,    46,    46,    46,    46,    46,    46,    46,
    46,    46,    83,    46,    46,    99,    46,    46,    46,    46,
    46,   105,   106,   107,    46,   109,    46,    46,    46,    46,
    46,    46,    46,    46,    46,    46,    46,    46,    46,    46,
    46,    46,    46,    46,    46,    46,    45,    45,    45,    45,
    45,    45,    45,    43,    45,     0,    45,    45,    45,    45,
    45,    45,    41,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,   162,   163,
   164,   165,    -1,    -1,    -1,   169,   170,    -1,   172,    -1,
   174,    -1,    -1,    -1,    -1,    -1,   180,   181
};
/* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
#line 3 "/usr/lib/bison.simple"
/* This file comes from bison-1.28.  */

/* Skeleton output parser for bison,
   Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* This is the parser code that is written into each bison parser
  when the %semantic_parser declaration is not specified in the grammar.
  It was written by Richard Stallman by simplifying the hairy parser
  used when %semantic_parser is specified.  */

#ifndef YYSTACK_USE_ALLOCA
#ifdef alloca
#define YYSTACK_USE_ALLOCA
#else /* alloca not defined */
#ifdef __GNUC__
#define YYSTACK_USE_ALLOCA
#define alloca __builtin_alloca
#else /* not GNU C.  */
#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi) || (defined (__sun) && defined (__i386))
#define YYSTACK_USE_ALLOCA
#include <alloca.h>
#else /* not sparc */
/* We think this test detects Watcom and Microsoft C.  */
/* This used to test MSDOS, but that is a bad idea
   since that symbol is in the user namespace.  */
#if (defined (_MSDOS) || defined (_MSDOS_)) && !defined (__TURBOC__)
#if 0 /* No need for malloc.h, which pollutes the namespace;
	 instead, just don't use alloca.  */
#include <malloc.h>
#endif
#else /* not MSDOS, or __TURBOC__ */
#if defined(_AIX)
/* I don't know what this was needed for, but it pollutes the namespace.
   So I turned it off.   rms, 2 May 1997.  */
/* #include <malloc.h>  */
 #pragma alloca
#define YYSTACK_USE_ALLOCA
#else /* not MSDOS, or __TURBOC__, or _AIX */
#if 0
#ifdef __hpux /* haible@ilog.fr says this works for HPUX 9.05 and up,
		 and on HPUX 10.  Eventually we can turn this on.  */
#define YYSTACK_USE_ALLOCA
#define alloca __builtin_alloca
#endif /* __hpux */
#endif
#endif /* not _AIX */
#endif /* not MSDOS, or __TURBOC__ */
#endif /* not sparc */
#endif /* not GNU C */
#endif /* alloca not defined */
#endif /* YYSTACK_USE_ALLOCA not defined */

#ifdef YYSTACK_USE_ALLOCA
#define YYSTACK_ALLOC alloca
#else
#define YYSTACK_ALLOC malloc
#endif

/* Note: there must be only one dollar sign in this file.
   It is replaced by the list of actions, each action
   as one case of the switch.  */

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		-2
#define YYEOF		0
#define YYACCEPT	goto yyacceptlab
#define YYABORT 	goto yyabortlab
#define YYERROR		goto yyerrlab1
/* Like YYERROR except do call yyerror.
   This remains here temporarily to ease the
   transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */
#define YYFAIL		goto yyerrlab
#define YYRECOVERING()  (!!yyerrstatus)
#define YYBACKUP(token, value) \
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    { yychar = (token), yylval = (value);			\
      yychar1 = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { yyerror ("syntax error: cannot back up"); YYERROR; }	\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

#ifndef YYPURE
#define YYLEX		yylex()
#endif

#ifdef YYPURE
#ifdef YYLSP_NEEDED
#ifdef YYLEX_PARAM
#define YYLEX		yylex(&yylval, &yylloc, YYLEX_PARAM)
#else
#define YYLEX		yylex(&yylval, &yylloc)
#endif
#else /* not YYLSP_NEEDED */
#ifdef YYLEX_PARAM
#define YYLEX		yylex(&yylval, YYLEX_PARAM)
#else
#define YYLEX		yylex(&yylval)
#endif
#endif /* not YYLSP_NEEDED */
#endif

/* If nonreentrant, generate the variables here */

#ifndef YYPURE

int	yychar;			/*  the lookahead symbol		*/
YYSTYPE	yylval;			/*  the semantic value of the		*/
				/*  lookahead symbol			*/

#ifdef YYLSP_NEEDED
YYLTYPE yylloc;			/*  location data for the lookahead	*/
				/*  symbol				*/
#endif

int yynerrs;			/*  number of parse errors so far       */
#endif  /* not YYPURE */

#if YYDEBUG != 0
int yydebug;			/*  nonzero means print parse trace	*/
/* Since this is uninitialized, it does not stop multiple parsers
   from coexisting.  */
#endif

/*  YYINITDEPTH indicates the initial size of the parser's stacks	*/

#ifndef	YYINITDEPTH
#define YYINITDEPTH 200
#endif

/*  YYMAXDEPTH is the maximum size the stacks can grow to
    (effective only if the built-in stack extension method is used).  */

#if YYMAXDEPTH == 0
#undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
#define YYMAXDEPTH 10000
#endif

/* Define __yy_memcpy.  Note that the size argument
   should be passed with type unsigned int, because that is what the non-GCC
   definitions require.  With GCC, __builtin_memcpy takes an arg
   of type size_t, but it can handle unsigned int.  */

#if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
#define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
#else				/* not GNU C or C++ */
#ifndef __cplusplus

/* This is the most reliable way to avoid incompatibilities
   in available built-in functions on various systems.  */
static void
__yy_memcpy (to, from, count)
     char *to;
     char *from;
     unsigned int count;
{
  register char *f = from;
  register char *t = to;
  register int i = count;

  while (i-- > 0)
    *t++ = *f++;
}

#else /* __cplusplus */

/* This is the most reliable way to avoid incompatibilities
   in available built-in functions on various systems.  */
static void
__yy_memcpy (char *to, char *from, unsigned int count)
{
  register char *t = to;
  register char *f = from;
  register int i = count;

  while (i-- > 0)
    *t++ = *f++;
}

#endif
#endif

#line 217 "/usr/lib/bison.simple"

/* The user can define YYPARSE_PARAM as the name of an argument to be passed
   into yyparse.  The argument should have type void *.
   It should actually point to an object.
   Grammar actions can access the variable by casting it
   to the proper pointer type.  */

#ifdef YYPARSE_PARAM
#ifdef __cplusplus
#define YYPARSE_PARAM_ARG void *YYPARSE_PARAM
#define YYPARSE_PARAM_DECL
#else /* not __cplusplus */
#define YYPARSE_PARAM_ARG YYPARSE_PARAM
#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
#endif /* not __cplusplus */
#else /* not YYPARSE_PARAM */
#define YYPARSE_PARAM_ARG
#define YYPARSE_PARAM_DECL
#endif /* not YYPARSE_PARAM */

/* Prevent warning if -Wstrict-prototypes.  */
#ifdef __GNUC__
#ifdef YYPARSE_PARAM
int yyparse (void *);
#else
int yyparse (void);
#endif
#endif

int
yyparse(YYPARSE_PARAM_ARG)
     YYPARSE_PARAM_DECL
{
  register int yystate;
  register int yyn;
  register short *yyssp;
  register YYSTYPE *yyvsp;
  int yyerrstatus;	/*  number of tokens to shift before error messages enabled */
  int yychar1 = 0;		/*  lookahead token as an internal (translated) token number */

  short	yyssa[YYINITDEPTH];	/*  the state stack			*/
  YYSTYPE yyvsa[YYINITDEPTH];	/*  the semantic value stack		*/

  short *yyss = yyssa;		/*  refer to the stacks thru separate pointers */
  YYSTYPE *yyvs = yyvsa;	/*  to allow yyoverflow to reallocate them elsewhere */

#ifdef YYLSP_NEEDED
  YYLTYPE yylsa[YYINITDEPTH];	/*  the location stack			*/
  YYLTYPE *yyls = yylsa;
  YYLTYPE *yylsp;

#define YYPOPSTACK   (yyvsp--, yyssp--, yylsp--)
#else
#define YYPOPSTACK   (yyvsp--, yyssp--)
#endif

  int yystacksize = YYINITDEPTH;
  int yyfree_stacks = 0;

#ifdef YYPURE
  int yychar;
  YYSTYPE yylval;
  int yynerrs;
#ifdef YYLSP_NEEDED
  YYLTYPE yylloc;
#endif
#endif

  YYSTYPE yyval;		/*  the variable used to return		*/
				/*  semantic values from the action	*/
				/*  routines				*/

  int yylen;

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Starting parse\n");
#endif

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss - 1;
  yyvsp = yyvs;
#ifdef YYLSP_NEEDED
  yylsp = yyls;
#endif

/* Push a new state, which is found in  yystate  .  */
/* In all cases, when you get here, the value and location stacks
   have just been pushed. so pushing a state here evens the stacks.  */
yynewstate:

  *++yyssp = yystate;

  if (yyssp >= yyss + yystacksize - 1)
    {
      /* Give user a chance to reallocate the stack */
      /* Use copies of these so that the &'s don't force the real ones into memory. */
      YYSTYPE *yyvs1 = yyvs;
      short *yyss1 = yyss;
#ifdef YYLSP_NEEDED
      YYLTYPE *yyls1 = yyls;
#endif

      /* Get the current used size of the three stacks, in elements.  */
      int size = yyssp - yyss + 1;

#ifdef yyoverflow
      /* Each stack pointer address is followed by the size of
	 the data in use in that stack, in bytes.  */
#ifdef YYLSP_NEEDED
      /* This used to be a conditional around just the two extra args,
	 but that might be undefined if yyoverflow is a macro.  */
      yyoverflow("parser stack overflow",
		 &yyss1, size * sizeof (*yyssp),
		 &yyvs1, size * sizeof (*yyvsp),
		 &yyls1, size * sizeof (*yylsp),
		 &yystacksize);
#else
      yyoverflow("parser stack overflow",
		 &yyss1, size * sizeof (*yyssp),
		 &yyvs1, size * sizeof (*yyvsp),
		 &yystacksize);
#endif

      yyss = yyss1; yyvs = yyvs1;
#ifdef YYLSP_NEEDED
      yyls = yyls1;
#endif
#else /* no yyoverflow */
      /* Extend the stack our own way.  */
      if (yystacksize >= YYMAXDEPTH)
	{
	  yyerror("parser stack overflow");
	  if (yyfree_stacks)
	    {
	      free (yyss);
	      free (yyvs);
#ifdef YYLSP_NEEDED
	      free (yyls);
#endif
	    }
	  return 2;
	}
      yystacksize *= 2;
      if (yystacksize > YYMAXDEPTH)
	yystacksize = YYMAXDEPTH;
#ifndef YYSTACK_USE_ALLOCA
      yyfree_stacks = 1;
#endif
      yyss = (short *) YYSTACK_ALLOC (yystacksize * sizeof (*yyssp));
      __yy_memcpy ((char *)yyss, (char *)yyss1,
		   size * (unsigned int) sizeof (*yyssp));
      yyvs = (YYSTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yyvsp));
      __yy_memcpy ((char *)yyvs, (char *)yyvs1,
		   size * (unsigned int) sizeof (*yyvsp));
#ifdef YYLSP_NEEDED
      yyls = (YYLTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yylsp));
      __yy_memcpy ((char *)yyls, (char *)yyls1,
		   size * (unsigned int) sizeof (*yylsp));
#endif
#endif /* no yyoverflow */

      yyssp = yyss + size - 1;
      yyvsp = yyvs + size - 1;
#ifdef YYLSP_NEEDED
      yylsp = yyls + size - 1;
#endif

#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Stack size increased to %d\n", yystacksize);
#endif

      if (yyssp >= yyss + yystacksize - 1)
	YYABORT;
    }

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Entering state %d\n", yystate);
#endif

  goto yybackup;
 yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYFLAG)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* yychar is either YYEMPTY or YYEOF
     or a valid token in external form.  */

  if (yychar == YYEMPTY)
    {
#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Reading a token: ");
#endif
      yychar = YYLEX;
    }

  /* Convert token to internal form (in yychar1) for indexing tables with */

  if (yychar <= 0)		/* This means end of input. */
    {
      yychar1 = 0;
      yychar = YYEOF;		/* Don't call YYLEX any more */

#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Now at end of input.\n");
#endif
    }
  else
    {
      yychar1 = YYTRANSLATE(yychar);

#if YYDEBUG != 0
      if (yydebug)
	{
	  fprintf (stderr, "Next token is %d (%s", yychar, yytname[yychar1]);
	  /* Give the individual parser a way to print the precise meaning
	     of a token, for further debugging info.  */
#ifdef YYPRINT
	  YYPRINT (stderr, yychar, yylval);
#endif
	  fprintf (stderr, ")\n");
	}
#endif
    }

  yyn += yychar1;
  if (yyn < 0 || yyn > YYLAST || yycheck[yyn] != yychar1)
    goto yydefault;

  yyn = yytable[yyn];

  /* yyn is what to do for this token type in this state.
     Negative => reduce, -yyn is rule number.
     Positive => shift, yyn is new state.
       New state is final state => don't bother to shift,
       just return success.
     0, or most negative number => error.  */

  if (yyn < 0)
    {
      if (yyn == YYFLAG)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }
  else if (yyn == 0)
    goto yyerrlab;

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Shifting token %d (%s), ", yychar, yytname[yychar1]);
#endif

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;
#ifdef YYLSP_NEEDED
  *++yylsp = yylloc;
#endif

  /* count tokens shifted since error; after three, turn off error status.  */
  if (yyerrstatus) yyerrstatus--;

  yystate = yyn;
  goto yynewstate;

/* Do the default action for the current state.  */
yydefault:

  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;

/* Do a reduction.  yyn is the number of a rule to reduce with.  */
yyreduce:
  yylen = yyr2[yyn];
  if (yylen > 0)
    yyval = yyvsp[1-yylen]; /* implement default value of the action */

#if YYDEBUG != 0
  if (yydebug)
    {
      int i;

      fprintf (stderr, "Reducing via rule %d (line %d), ",
	       yyn, yyrline[yyn]);

      /* Print the symbols being reduced, and their result.  */
      for (i = yyprhs[yyn]; yyrhs[i] > 0; i++)
	fprintf (stderr, "%s ", yytname[yyrhs[i]]);
      fprintf (stderr, " -> %s\n", yytname[yyr1[yyn]]);
    }
#endif


  switch (yyn) {

case 1:
#line 180 "config_parse.y"
{ local_config = yyvsp[0].glist; ;
    break;}
case 2:
#line 183 "config_parse.y"
{{
						if(yyvsp[-1].kv) {
							yyval.glist = g_list_prepend(yyvsp[0].glist, yyvsp[-1].kv);
						} else {
							yyval.glist = yyvsp[0].glist;
						}
					};
    break;}
case 3:
#line 190 "config_parse.y"
{{ 
						if(yyvsp[0].kv) {
							yyval.glist = g_list_append(NULL, yyvsp[0].kv);
						} else {
							yyval.glist = NULL;
						}
					};
    break;}
case 4:
#line 199 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 5:
#line 200 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 6:
#line 201 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 7:
#line 202 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 8:
#line 203 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 9:
#line 204 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 10:
#line 205 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 11:
#line 206 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 12:
#line 207 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 13:
#line 208 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 14:
#line 209 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 15:
#line 210 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 16:
#line 211 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 17:
#line 212 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 18:
#line 213 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 19:
#line 214 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 20:
#line 215 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 21:
#line 216 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 22:
#line 217 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 23:
#line 218 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 24:
#line 219 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 25:
#line 220 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 26:
#line 221 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 27:
#line 222 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 28:
#line 223 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 29:
#line 224 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 30:
#line 225 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 31:
#line 226 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 32:
#line 227 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 33:
#line 228 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 34:
#line 229 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 35:
#line 230 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 36:
#line 231 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 37:
#line 232 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 38:
#line 233 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 39:
#line 234 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 40:
#line 235 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 41:
#line 236 "config_parse.y"
{ yyval.kv = yyvsp[-1].kv; ;
    break;}
case 42:
#line 237 "config_parse.y"
{ yyval.kv = NULL;;
    break;}
case 43:
#line 241 "config_parse.y"
{{
			KEY_VALUE *r, *r2;
			MIME_EXTENSIONS *m;
			GString *extension;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("Mime_Extension");
			r2 = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->value = r2;
			extension = g_string_new(yyvsp[-5].gstring->str);
			extension = g_string_prepend(extension,"a.");
			r2->key = g_string_new(gnome_mime_type_or_default(extension->str,NULL));
			g_string_free(extension, TRUE);
			m = (MIME_EXTENSIONS*)g_malloc(sizeof(MIME_EXTENSIONS));
			r2->value = m;
			if(r2->key)
				m->mime = r2->key;
			else
				m->mime = NULL;
			m->prog = yyvsp[-4].gstring;
			m->arg = yyvsp[-3].gstring;
			g_string_free(yyvsp[-2].gstring, TRUE);
			g_string_free(yyvsp[-1].gstring, TRUE);
			if(test_plugin_existence(m->prog) == FALSE)
				m->state = FALSE;
			else
				m->state = yyvsp[0].val;
			yyval.kv = r;
		};
    break;}
case 44:
#line 273 "config_parse.y"
{{
			KEY_VALUE *r, *r2;
			MIME_EXTENSIONS *m;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("Mime_Extension");
			r2 = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->value = r2;
			r2->key = yyvsp[-3].gstring;
			m = (MIME_EXTENSIONS*)g_malloc(sizeof(MIME_EXTENSIONS));
			r2->value = m;
			m->mime = yyvsp[-3].gstring;
			m->prog = yyvsp[-2].gstring;
			m->arg = yyvsp[-1].gstring;
			if(test_plugin_existence(m->prog) == FALSE)
				m->state = FALSE;
			else
				m->state = yyvsp[0].val;
			yyval.kv = r;
		};
    break;}
case 45:
#line 296 "config_parse.y"
{{
			KEY_VALUE *r;
			MIME_EXTENSIONS *m;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("Default_Mime_Extension");
			m = (MIME_EXTENSIONS*)g_malloc(sizeof(MIME_EXTENSIONS));
			r->value = m;
			m->mime = NULL;
			m->prog = yyvsp[-1].gstring;
			m->arg = yyvsp[0].gstring;
			if(test_plugin_existence(m->prog) == FALSE)
				m->state = FALSE;
			else
				m->state = TRUE;
			yyval.kv = r;
		};
    break;}
case 46:
#line 316 "config_parse.y"
{{
			KEY_VALUE *r, *r2;
			MIME_VFS_EXTENSIONS *me;
			GString *extension;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("VfsExtension");
			r2 = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->value = r2;
			extension = g_string_new(yyvsp[-8].gstring->str);
			extension = g_string_prepend(extension,"a.");
			r2->key = g_string_new(gnome_mime_type_or_default(extension->str,NULL));
			g_string_free(extension, TRUE);
			me = (MIME_VFS_EXTENSIONS*)g_malloc(sizeof(MIME_VFS_EXTENSIONS));
			r2->value = me;
			if(r2->key)
				me->mime = r2->key;
			else
				me->mime = NULL;
			me->prog = yyvsp[-7].gstring;
			me->args = yyvsp[-6].gstring;
			me->separator = yyvsp[-5].gstring;
			me->date = yyvsp[-4].val;
			me->date_format = yyvsp[-3].gstring;
			me->size = yyvsp[-2].val;
			me->name = yyvsp[-1].val;
			if(test_plugin_existence(me->prog) == FALSE)
				me->state = FALSE;
			else
				me->state = yyvsp[0].val;
			yyval.kv = r;
		};
    break;}
case 47:
#line 351 "config_parse.y"
{{
			KEY_VALUE *r, *r2;
			MIME_VFS_EXTENSIONS *ve;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("VfsExtension");
			r2 = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->value = r2;
			r2->key = yyvsp[-8].gstring;
			ve = (MIME_VFS_EXTENSIONS*)g_malloc(sizeof(MIME_VFS_EXTENSIONS));
			r2->value = ve;
			ve->mime = yyvsp[-8].gstring;
			ve->prog = yyvsp[-7].gstring;
			ve->args = yyvsp[-6].gstring;
			ve->separator = yyvsp[-5].gstring;
			ve->date = yyvsp[-4].val;
			ve->date_format = yyvsp[-3].gstring;
			ve->size = yyvsp[-2].val;
			ve->name = yyvsp[-1].val;
			if(test_plugin_existence(ve->prog) == FALSE)
				ve->state = FALSE;
			else
				ve->state = yyvsp[0].val;
			yyval.kv = r;
		};
    break;}
case 48:
#line 379 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("MountProgram");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 49:
#line 390 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("UmountProgram");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 50:
#line 401 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("EjectProgram");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 51:
#line 412 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("MountPoint");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 52:
#line 422 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("UseAutomount");
			r->value = GINT_TO_POINTER(yyvsp[0].gbool);
			yyval.kv = r;
		};
    break;}
case 53:
#line 432 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("MountRetry");
			r->value = GINT_TO_POINTER(yyvsp[0].val);
			yyval.kv = r;
		};
    break;}
case 54:
#line 443 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("OptionDus");
			r->value = GINT_TO_POINTER(yyvsp[0].gbool);
			yyval.kv = r;
		};
    break;}
case 55:
#line 453 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("OptionWarnMount");
			r->value = GINT_TO_POINTER(yyvsp[0].gbool);
			yyval.kv = r;
		};
    break;}
case 56:
#line 463 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("OptionEject");
			r->value = GINT_TO_POINTER(yyvsp[0].gbool);
			yyval.kv = r;
		};
    break;}
case 57:
#line 474 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("CompressionLevel");
			r->value = GINT_TO_POINTER(yyvsp[0].val);
			yyval.kv = r;
		};
    break;}
case 58:
#line 485 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("TestVFS");
			r->value = GINT_TO_POINTER(yyvsp[0].val);
			yyval.kv = r;
		};
    break;}
case 59:
#line 496 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("ReadInformation");
			r->value = GINT_TO_POINTER(yyvsp[0].gbool);
			yyval.kv = r;
		};
    break;}
case 60:
#line 507 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("UseDefaultMimePlugin");
			r->value = GINT_TO_POINTER(yyvsp[0].gbool);
			yyval.kv = r;
		};
    break;}
case 61:
#line 518 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("DbClickForInfo");
			r->value = GINT_TO_POINTER(yyvsp[0].gbool);
			yyval.kv = r;
		};
    break;}
case 62:
#line 531 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("DisplayDirSize");
			r->value = GINT_TO_POINTER(yyvsp[0].gbool);
			yyval.kv = r;
		};
    break;}
case 63:
#line 547 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("AddExtIcon");
			r->value = yyvsp[0].glist;
			yyval.kv = r;
		};
    break;}
case 64:
#line 558 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("AddMimeIcon");
			r->value = yyvsp[0].glist;
			yyval.kv = r;
		};
    break;}
case 65:
#line 569 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("DefaultFileIcon");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 66:
#line 580 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("DefaultDirIcon");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 67:
#line 591 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("DefaultDiskIcon");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 68:
#line 602 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("DefaultUnreadableIcon");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 69:
#line 613 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("DefaultVfsIcon");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 70:
#line 624 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("DefaultOpenedDirIcon");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 71:
#line 635 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("DefaultOpenedDiskIcon");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 72:
#line 646 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("DefaultOpenedVfsIcon");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 73:
#line 657 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("DateFormat");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
		};
    break;}
case 74:
#line 666 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("DateFormatMode");
			r->value = NULL;
			yyval.kv = r;
		};
    break;}
case 75:
#line 677 "config_parse.y"
{{
			KEY_VALUE *r;
#if defined(__DEBUG__)
  GML_set_mode_active ();
  GML_log_point(1,"lecture");
#endif

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("RecentFile");
			r->value = yyvsp[0].gstring;
			yyval.kv = r;
#if defined(__DEBUG__)
  GML_set_mode_passive ();
#endif
		};
    break;}
case 76:
#line 695 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("RecentFilesMax");
			r->value = GINT_TO_POINTER(yyvsp[0].val);
			yyval.kv = r;
		};
    break;}
case 77:
#line 706 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("PreviousSearchMode");
			r->value = GINT_TO_POINTER(yyvsp[0].val);
			yyval.kv = r;
		};
    break;}
case 78:
#line 717 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("SaveOnlyUsedCategories");
			r->value = GINT_TO_POINTER(yyvsp[0].gbool);
			yyval.kv = r;
		};
    break;}
case 79:
#line 728 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("ScanMimeTypes");
			r->value = GINT_TO_POINTER(yyvsp[0].gbool);
			yyval.kv = r;
		};
    break;}
case 80:
#line 739 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("AddMIMEToSkip");
			r->value = g_list_append(NULL,yyvsp[-1].gstring);
			r->value = g_list_append(r->value,GINT_TO_POINTER(yyvsp[0].val));
			yyval.kv = r;
		};
    break;}
case 81:
#line 751 "config_parse.y"
{{
			KEY_VALUE *r;

			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
			r->key = g_string_new("MainWindowPosition");
			r->value = g_list_append(NULL,GINT_TO_POINTER(yyvsp[-4].val));
			r->value = g_list_append(r->value,GINT_TO_POINTER(yyvsp[-3].val));
			r->value = g_list_append(r->value,GINT_TO_POINTER(yyvsp[-2].val));
			r->value = g_list_append(r->value,GINT_TO_POINTER(yyvsp[-1].val));
			r->value = g_list_append(r->value,GINT_TO_POINTER(yyvsp[0].gbool));
			yyval.kv = r;
		};
    break;}
case 82:
#line 767 "config_parse.y"
{ yyval.glist = g_list_append(NULL, yyvsp[0].gstring); ;
    break;}
case 83:
#line 768 "config_parse.y"
{ yyval.glist = g_list_prepend(yyvsp[0].glist, yyvsp[-1].gstring ); ;
    break;}
case 84:
#line 771 "config_parse.y"
{ yyval.gstring = g_string_new(yyvsp[0].string); ;
    break;}
case 85:
#line 772 "config_parse.y"
{ 
							gchar *s;
							GString *g;
							s = yyvsp[0].string;
							s++;
							g = g_string_new(s);
							yyval.gstring = g_string_truncate(g, g->len-1);
						;
    break;}
}
   /* the action file gets copied in in place of this dollarsign */
#line 543 "/usr/lib/bison.simple"

  yyvsp -= yylen;
  yyssp -= yylen;
#ifdef YYLSP_NEEDED
  yylsp -= yylen;
#endif

#if YYDEBUG != 0
  if (yydebug)
    {
      short *ssp1 = yyss - 1;
      fprintf (stderr, "state stack now");
      while (ssp1 != yyssp)
	fprintf (stderr, " %d", *++ssp1);
      fprintf (stderr, "\n");
    }
#endif

  *++yyvsp = yyval;

#ifdef YYLSP_NEEDED
  yylsp++;
  if (yylen == 0)
    {
      yylsp->first_line = yylloc.first_line;
      yylsp->first_column = yylloc.first_column;
      yylsp->last_line = (yylsp-1)->last_line;
      yylsp->last_column = (yylsp-1)->last_column;
      yylsp->text = 0;
    }
  else
    {
      yylsp->last_line = (yylsp+yylen-1)->last_line;
      yylsp->last_column = (yylsp+yylen-1)->last_column;
    }
#endif

  /* Now "shift" the result of the reduction.
     Determine what state that goes to,
     based on the state we popped back to
     and the rule number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTBASE] + *yyssp;
  if (yystate >= 0 && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTBASE];

  goto yynewstate;

yyerrlab:   /* here on detecting error */

  if (! yyerrstatus)
    /* If not already recovering from an error, report this error.  */
    {
      ++yynerrs;

#ifdef YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (yyn > YYFLAG && yyn < YYLAST)
	{
	  int size = 0;
	  char *msg;
	  int x, count;

	  count = 0;
	  /* Start X at -yyn if nec to avoid negative indexes in yycheck.  */
	  for (x = (yyn < 0 ? -yyn : 0);
	       x < (sizeof(yytname) / sizeof(char *)); x++)
	    if (yycheck[x + yyn] == x)
	      size += strlen(yytname[x]) + 15, count++;
	  msg = (char *) malloc(size + 15);
	  if (msg != 0)
	    {
	      strcpy(msg, "parse error");

	      if (count < 5)
		{
		  count = 0;
		  for (x = (yyn < 0 ? -yyn : 0);
		       x < (sizeof(yytname) / sizeof(char *)); x++)
		    if (yycheck[x + yyn] == x)
		      {
			strcat(msg, count == 0 ? ", expecting `" : " or `");
			strcat(msg, yytname[x]);
			strcat(msg, "'");
			count++;
		      }
		}
	      yyerror(msg);
	      free(msg);
	    }
	  else
	    yyerror ("parse error; also virtual memory exceeded");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror("parse error");
    }

  goto yyerrlab1;
yyerrlab1:   /* here on error raised explicitly by an action */

  if (yyerrstatus == 3)
    {
      /* if just tried and failed to reuse lookahead token after an error, discard it.  */

      /* return failure if at end of input */
      if (yychar == YYEOF)
	YYABORT;

#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Discarding token %d (%s).\n", yychar, yytname[yychar1]);
#endif

      yychar = YYEMPTY;
    }

  /* Else will try to reuse lookahead token
     after shifting the error token.  */

  yyerrstatus = 3;		/* Each real token shifted decrements this */

  goto yyerrhandle;

yyerrdefault:  /* current state does not do anything special for the error token. */

#if 0
  /* This is wrong; only states that explicitly want error tokens
     should shift them.  */
  yyn = yydefact[yystate];  /* If its default is to accept any token, ok.  Otherwise pop it.*/
  if (yyn) goto yydefault;
#endif

yyerrpop:   /* pop the current state because it cannot handle the error token */

  if (yyssp == yyss) YYABORT;
  yyvsp--;
  yystate = *--yyssp;
#ifdef YYLSP_NEEDED
  yylsp--;
#endif

#if YYDEBUG != 0
  if (yydebug)
    {
      short *ssp1 = yyss - 1;
      fprintf (stderr, "Error: state stack now");
      while (ssp1 != yyssp)
	fprintf (stderr, " %d", *++ssp1);
      fprintf (stderr, "\n");
    }
#endif

yyerrhandle:

  yyn = yypact[yystate];
  if (yyn == YYFLAG)
    goto yyerrdefault;

  yyn += YYTERROR;
  if (yyn < 0 || yyn > YYLAST || yycheck[yyn] != YYTERROR)
    goto yyerrdefault;

  yyn = yytable[yyn];
  if (yyn < 0)
    {
      if (yyn == YYFLAG)
	goto yyerrpop;
      yyn = -yyn;
      goto yyreduce;
    }
  else if (yyn == 0)
    goto yyerrpop;

  if (yyn == YYFINAL)
    YYACCEPT;

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Shifting error token, ");
#endif

  *++yyvsp = yylval;
#ifdef YYLSP_NEEDED
  *++yylsp = yylloc;
#endif

  yystate = yyn;
  goto yynewstate;

 yyacceptlab:
  /* YYACCEPT comes here.  */
  if (yyfree_stacks)
    {
      free (yyss);
      free (yyvs);
#ifdef YYLSP_NEEDED
      free (yyls);
#endif
    }
  return 0;

 yyabortlab:
  /* YYABORT comes here.  */
  if (yyfree_stacks)
    {
      free (yyss);
      free (yyvs);
#ifdef YYLSP_NEEDED
      free (yyls);
#endif
    }
  return 1;
}
#line 812 "config_parse.y"


int
yyerror (char *s)
{
  printf (_("Error parsing the config file: %s\n"), s);
  exit (0);
}

gboolean check_supermount (CONFIG * my_config)
{
  FILE *fp;
  char line[1024];
  char s1[1024];
  char s2[1024];
  char s3[1024];
  int rc;

#ifdef OS_LINUX
  fp = fopen ("/proc/mounts", "r");
  if (fp == NULL)
    {
      ERROR_DIALOG (_("Unable to open /proc/mounts\n"), main_window);
    }

  while (fgets (line, sizeof (line), fp) != 0)
    {
      rc = sscanf (line, "%1023s %1023s %1023s", s1, s2, s3);
      if ((rc >= 3) && (strcmp (s2, my_config->mount_point->str) == 0)
	  && (strcmp (s3, "supermount") == 0))
	{
	  fclose (fp);
	  return TRUE;
	}
    }
  fclose (fp);
#endif
  return FALSE;
}


void
config_struct_free_1 (GList * gl)
{
  g_string_free (((KEY_VALUE *) (gl->data))->key, TRUE);
  g_free(gl->data);
  local_config = g_list_remove_link (local_config, gl);
  g_list_free_1 (gl);
}

#define GET_TOKEN ((KEY_VALUE*)(glist_ptr1->data))->value
#define NEXT_TOKEN config_struct_free_1(glist_ptr1); glist_ptr1 = local_config
#define IS_TOKEN(my_token) (strcmp((((KEY_VALUE*)(glist_ptr1->data))->key)->str,my_token) == 0)
#define CONFIG_FILE_VERSION 1

CONFIG *
init_config (GtkWidget * w)
{
/* Returns the config file "config_file->str" formated into the structure CONFIG */
  GString *conf_file;
  GList *glist_ptr1;
  CONFIG *my_config;
  FILE *rcfile;
  GList *gl1, *gl2;
  GString *gs;
  PIX *pix;
  GtkStyle *style;
  gchar *mime;
  gchar *path;
  GString *tmpstr;

  conf_file = g_string_new (g_get_home_dir ());
  conf_file =
    g_string_append (conf_file, USER_CONFIG_DIR "/" USER_CONFIG_FILE);
  if (!g_file_test (conf_file->str, G_FILE_TEST_ISFILE))
    {
      g_string_free (conf_file, TRUE);
      conf_file = g_string_new (DATA_DIR "/gtktalog/gtktalog.cf");
      if (!g_file_test (conf_file->str, G_FILE_TEST_ISFILE))
	{
	  ERROR_DIALOG (_("Could not find config file"), main_window);
	  exit (-1);
	}
    }

  local_config = NULL;

  style = gtk_widget_get_style (GTK_WIDGET (w));

  rcfile = fopen (conf_file->str, "r");
  if (rcfile)
    {

      /* Init some fields of my_config */
      my_config = (CONFIG *) g_malloc (sizeof (CONFIG));
      my_config->pix_paths = g_tree_new ((GCompareFunc) strcmp);
      my_config->mime_icons = g_tree_new ((GCompareFunc) g_strcasecmp);
      my_config->mount = g_string_new ("/bin/mount");
      my_config->umount = g_string_new ("/bin/umount");
      my_config->eject_prog = g_string_new ("/usr/bin/eject");
      my_config->mount_point = g_string_new ("/mnt/cdrom");
      my_config->use_automount = FALSE;
      my_config->mount_retry = 0;
      my_config->mime_extensions = g_tree_new ((GCompareFunc) strcmp);
      my_config->mime_vfs_extensions = g_tree_new ((GCompareFunc) strcmp);
      my_config->mime_to_skip_during_a_scan =
	g_tree_new ((GCompareFunc) strcmp);
      my_config->use_du_s = TRUE;
      my_config->warn_mount = FALSE;
      my_config->eject_disk = TRUE;
      my_config->getInformation = TRUE;
      my_config->testvfs = TEST_VFS_NO;
      my_config->compression_level = 9;
      my_config->default_file_pix = NULL;
      my_config->default_dir_pix = NULL;
      my_config->default_disk_pix = NULL;
      my_config->default_unreadable_pix = NULL;
      my_config->default_vfs_pix = NULL;
      my_config->default_opened_dir_pix = NULL;
      my_config->default_opened_disk_pix = NULL;
      my_config->default_opened_vfs_pix = NULL;
      my_config->date_format = g_strdup ("%d/%m/%Y %H:%M:%S");
      my_config->display_dir_size = TRUE;
      my_config->recent_files = NULL;
      my_config->nb_max_recent_files = 4;
      my_config->previous_search_mode = EVERYTHING_MATCHES;
      my_config->save_only_used_categories = FALSE;
      my_config->scan_mime_types = FALSE;
      my_config->use_default_information_plugin = TRUE;
      my_config->default_information_plugin = NULL;
      my_config->mainwindow_x = 10;
      my_config->mainwindow_y = 10;
      my_config->mainwindow_w = 640;
      my_config->mainwindow_h = 480;
      my_config->mainwindow_save_xywh = FALSE;
      my_config->sort_column = 0;
      my_config->currently_displayed_recent_files = 0;

      /* Parse the config file */
      yyrestart (rcfile);
      yyparse ();
      fclose (rcfile);

      /* Fills some fields of my_config with the parsed data */

      glist_ptr1 = local_config;
      while (glist_ptr1)
	{
	  if (IS_TOKEN ("AddExtIcon"))
	    {
	      /* Icon */
	      gl1 = GET_TOKEN;
	      pix =
		new_pix_from_filename (w, style,
				       ((GString *) (gl1->data))->str,
				       my_config);

	      g_string_free (((GString *) (gl1->data)), TRUE);
	      gl2 = g_list_next (gl1);
	      while (gl2)
		{
		  if (pix)
		    {
		      tmpstr = g_string_new (((GString *) (gl2->data))->str);
		      tmpstr = g_string_prepend (tmpstr, "a.");
		      mime =
			g_strdup (gnome_mime_type_or_default
				  (tmpstr->str, NULL));
		      g_string_free (tmpstr, TRUE);
		      if (mime)
			{
			  g_tree_insert (my_config->mime_icons, mime, pix);
			}
		    }
		  g_string_free (gl2->data, TRUE);
		  gl2 = g_list_next (gl2);
		}

	      g_list_free (gl1);


	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("AddMimeIcon"))
	    {
	      /* Icon */
	      gl1 = GET_TOKEN;
	      pix =
		new_pix_from_filename (w, style,
				       ((GString *) (gl1->data))->str,
				       my_config);
	      g_string_free (((GString *) (gl1->data)), TRUE);
	      gl2 = g_list_next (gl1);
	      while (gl2)
		{
		  if (pix)
		    {
		      g_tree_insert (my_config->mime_icons,
				     (mime = g_strdup (
						       ((GString
							 *) (gl2->
							     data))->str)),
				     pix);
		    }
		  g_string_free (gl2->data, TRUE);
		  gl2 = g_list_next (gl2);
		}

	      g_list_free (gl1);


	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("DefaultFileIcon"))
	    {
	      gs = GET_TOKEN;
	      my_config->default_file_pix = new_pix_from_filename (w, style,
								   (path =
								    g_strdup
								    (gs->str)),
								   my_config);
	      g_string_free (gs, TRUE);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("DefaultDirIcon"))
	    {
	      gs = GET_TOKEN;
	      my_config->default_dir_pix = new_pix_from_filename (w, style,
								  (path =
								   g_strdup
								   (gs->str)),
								  my_config);
	      g_string_free (gs, TRUE);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("DefaultDiskIcon"))
	    {
	      gs = GET_TOKEN;
	      my_config->default_disk_pix = new_pix_from_filename (w, style,
								   (path =
								    g_strdup
								    (gs->str)),
								   my_config);
	      g_string_free (gs, TRUE);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("DefaultUnreadableIcon"))
	    {
	      gs = GET_TOKEN;

	      my_config->default_unreadable_pix = new_pix_from_filename (w,
									 style,
									 (path
									  =
									  g_strdup
									  (gs->str)),
									 my_config);
	      g_string_free (gs, TRUE);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("DefaultVfsIcon"))
	    {
	      gs = GET_TOKEN;
	      my_config->default_vfs_pix = new_pix_from_filename (w, style,
								  (path =
								   g_strdup
								   (gs->str)),
								  my_config);
	      g_string_free (gs, TRUE);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("DefaultOpenedDirIcon"))
	    {
	      gs = GET_TOKEN;
	      my_config->default_opened_dir_pix =
		new_pix_from_filename (w, style, (path = g_strdup (gs->str)),
				       my_config);
	      g_string_free (gs, TRUE);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("DefaultOpenedDiskIcon"))
	    {
	      gs = GET_TOKEN;
	      my_config->default_opened_disk_pix =
		new_pix_from_filename (w, style, (path = g_strdup (gs->str)),
				       my_config);
	      g_string_free (gs, TRUE);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("DefaultOpenedVfsIcon"))
	    {
	      gs = GET_TOKEN;
	      my_config->default_opened_vfs_pix =
		new_pix_from_filename (w, style, (path = g_strdup (gs->str)),
				       my_config);
	      g_string_free (gs, TRUE);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("MountProgram"))
	    {
	      gs = GET_TOKEN;
	      g_string_free (my_config->mount, TRUE);
	      my_config->mount = gs;
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("UmountProgram"))
	    {
	      gs = GET_TOKEN;
	      g_string_free (my_config->umount, TRUE);
	      my_config->umount = gs;
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("EjectProgram"))
	    {
	      gs = GET_TOKEN;
	      g_string_free (my_config->eject_prog, TRUE);
	      my_config->eject_prog = gs;
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("MountPoint"))
	    {
	      gs = GET_TOKEN;
	      g_string_free (my_config->mount_point, TRUE);
	      my_config->mount_point = gs;
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("UseAutomount"))
	    {
	      gs = GET_TOKEN;
	      my_config->use_automount = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("MountRetry"))
	    {
	      gs = GET_TOKEN;
	      my_config->mount_retry = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("OptionDus"))
	    {
	      gs = GET_TOKEN;
	      my_config->use_du_s = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("OptionWarnMount"))
	    {
	      gs = GET_TOKEN;
	      my_config->warn_mount = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("OptionEject"))
	    {
	      gs = GET_TOKEN;
	      my_config->eject_disk = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("CompressionLevel"))
	    {
	      gs = GET_TOKEN;
	      my_config->compression_level = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("TestVFS"))
	    {
	      gs = GET_TOKEN;
	      my_config->testvfs = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("Mime_Extension"))
	    {
	      gs = GET_TOKEN;
	      g_tree_insert (my_config->mime_extensions,
			     ((MIME_EXTENSIONS *) ((KEY_VALUE *) gs)->value)->
			     mime->str, ((KEY_VALUE *) gs)->value);
	      g_free (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("Default_Mime_Extension"))
	    {
	      gs = GET_TOKEN;
	      if (my_config->default_information_plugin)
		{
		  g_string_free (my_config->default_information_plugin->prog,
				 TRUE);
		  g_string_free (my_config->default_information_plugin->arg,
				 TRUE);
		  g_free (my_config->default_information_plugin);
		}
	      my_config->default_information_plugin =
		(MIME_EXTENSIONS *) g_malloc (sizeof (MIME_EXTENSIONS));
	      my_config->default_information_plugin->mime = NULL;
	      my_config->default_information_plugin->prog =
		((MIME_EXTENSIONS *) gs)->prog;
	      my_config->default_information_plugin->arg =
		((MIME_EXTENSIONS *) gs)->arg;
	      my_config->default_information_plugin->state =
		((MIME_EXTENSIONS *) gs)->state;
	      g_free (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("UseDefaultMimePlugin"))
	    {
	      gs = GET_TOKEN;
	      my_config->use_default_information_plugin =
		GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("VfsExtension"))
	    {
	      gs = GET_TOKEN;
	      mime = ((MIME_VFS_EXTENSIONS
		       *) ((KEY_VALUE *) gs)->value)->mime->str;
	      if (mime)
		{
		  g_tree_insert (my_config->mime_vfs_extensions, mime,
				 ((KEY_VALUE *) gs)->value);
		  g_free (gs);
		}
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("AddMIMEToSkip"))
	    {
	      /* Icon */
	      gl1 = GET_TOKEN;
	      gl2 = g_list_next (gl1);
	      g_tree_insert (my_config->mime_to_skip_during_a_scan,
			     (mime = g_strdup (
					       ((GString
						 *) (gl1->data))->str)),
			     gl2->data);

	      g_string_free (gl1->data, TRUE);

	      g_list_free (gl1);


	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("ReadInformation"))
	    {
	      gs = GET_TOKEN;
	      my_config->getInformation = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("DbClickForInfo"))
	    {
	      gs = GET_TOKEN;
	      my_config->dbclick_opens_info = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("DisplayDirSize"))
	    {
	      gs = GET_TOKEN;
	      my_config->display_dir_size = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("DateFormat"))
	    {
	      gs = GET_TOKEN;
	      if (my_config->date_format)
		g_free (my_config->date_format);
	      my_config->date_format = g_strdup (gs->str);
	      g_string_free (gs, TRUE);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("DateFormatMode"))
	    {
	      gs = GET_TOKEN;
	      my_config->date_format = NULL;
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("RecentFile"))
	    {
#if defined(__DEBUG__)
	      GML_set_mode_active ();
	      GML_log_point (1, "config");
#endif
	      gs = GET_TOKEN;
	      my_config->recent_files =
		add_file_to_recent_files (my_config->recent_files,
					  my_config->nb_max_recent_files,
					  gs->str);
	      g_string_free (gs, TRUE);
	      NEXT_TOKEN;
#if defined(__DEBUG__)
	      GML_set_mode_passive ();
#endif
	    }
	  else if (IS_TOKEN ("RecentFilesMax"))
	    {
	      gs = GET_TOKEN;
	      my_config->nb_max_recent_files = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("PreviousSearchMode"))
	    {
	      gs = GET_TOKEN;
	      my_config->previous_search_mode = GPOINTER_TO_INT (gs);
	      if (my_config->previous_search_mode >= STRING_SM_NB)
		my_config->previous_search_mode = EVERYTHING_MATCHES;
	      if (my_config->previous_search_mode < 0)
		my_config->previous_search_mode = EVERYTHING_MATCHES;
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("SaveOnlyUsedCategories"))
	    {
	      gs = GET_TOKEN;
	      my_config->save_only_used_categories = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("ScanMimeTypes"))
	    {
	      gs = GET_TOKEN;
	      my_config->scan_mime_types = GPOINTER_TO_INT (gs);
	      NEXT_TOKEN;
	    }
	  else if (IS_TOKEN ("MainWindowPosition"))
	    {
	      gs = GET_TOKEN;
	      gl1 = (GList *) gs;
	      my_config->mainwindow_x = GPOINTER_TO_INT (gl1->data);
	      gl1 = gl1->next;
	      my_config->mainwindow_y = GPOINTER_TO_INT (gl1->data);
	      gl1 = gl1->next;
	      my_config->mainwindow_w = GPOINTER_TO_INT (gl1->data);
	      gl1 = gl1->next;
	      my_config->mainwindow_h = GPOINTER_TO_INT (gl1->data);
	      gl1 = gl1->next;
	      my_config->mainwindow_save_xywh = GPOINTER_TO_INT (gl1->data);
	      g_list_free ((GList *) gs);
	      NEXT_TOKEN;
	    }
	  else
	    {
	      glist_ptr1 = g_list_next (glist_ptr1);
	    }
	}
      my_config->use_supermount = check_supermount (my_config);
      if (my_config->default_file_pix == NULL)
	{
	  my_config->default_file_pix = new_pix_from_filename (w, style,
							       DEFAULTFILEICONPATH,
							       my_config);
	  if (!my_config->default_file_pix)
	    exit (-1);
	}
      if (my_config->default_dir_pix == NULL)
	{
	  my_config->default_dir_pix = new_pix_from_filename (w, style,
							      DEFAULTDIRICONPATH,
							      my_config);
	  if (!my_config->default_dir_pix)
	    exit (-1);
	}
      if (my_config->default_disk_pix == NULL)
	{
	  my_config->default_disk_pix = new_pix_from_filename (w, style,
							       DEFAULTDISKICONPATH,
							       my_config);
	  if (!my_config->default_disk_pix)
	    exit (-1);
	}
      if (my_config->default_unreadable_pix == NULL)
	{
	  my_config->default_unreadable_pix = new_pix_from_filename (w, style,
								     DEFAULTUNREADABLEICONPATH,
								     my_config);
	  if (!my_config->default_unreadable_pix)
	    exit (-1);
	}
      if (my_config->default_vfs_pix == NULL)
	{
	  my_config->default_vfs_pix = new_pix_from_filename (w, style,
							      DEFAULTVFSICONPATH,
							      my_config);
	  if (!my_config->default_vfs_pix)
	    exit (-1);
	}
      if (my_config->default_opened_dir_pix == NULL)
	{
	  my_config->default_opened_dir_pix = new_pix_from_filename (w, style,
								     DEFAULTOPENEDDIRICONPATH,
								     my_config);
	  if (!my_config->default_opened_dir_pix)
	    exit (-1);
	}
      if (my_config->default_opened_disk_pix == NULL)
	{
	  my_config->default_opened_disk_pix =
	    new_pix_from_filename (w, style, DEFAULTOPENEDDISKICONPATH,
				   my_config);
	  if (!my_config->default_opened_disk_pix)
	    exit (-1);
	}
      if (my_config->default_opened_vfs_pix == NULL)
	{
	  my_config->default_opened_vfs_pix = new_pix_from_filename (w, style,
								     DEFAULTOPENEDVFSICONPATH,
								     my_config);
	  if (!my_config->default_opened_vfs_pix)
	    exit (-1);
	}
      if (my_config->eject_prog)
	{
	  if (my_config->eject_prog->len <= 0)
	    {
	      my_config->eject_disk = FALSE;
	    }
	}
      else
	{
	  my_config->eject_disk = FALSE;
	}
      if (!my_config->default_information_plugin)
	{
	  my_config->use_default_information_plugin = FALSE;
	  my_config->default_information_plugin =
	    (MIME_EXTENSIONS *) g_malloc (sizeof (MIME_EXTENSIONS));
	  my_config->default_information_plugin->mime = NULL;
	  my_config->default_information_plugin->prog = g_string_new ("");
	  my_config->default_information_plugin->arg = g_string_new ("");
	  my_config->default_information_plugin->state = FALSE;
	}
    }
  else
    {
      my_config = NULL;
    }
  g_string_free (conf_file, TRUE);
  return (my_config);
}
